
  exports.contentNegotiator = function(req, res, next) {
    var type, _i, _len, _ref;
    if (!req.acceptableTypes) return next();
    _ref = req.acceptableTypes;
    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
      type = _ref[_i];
      if (this.html && type === 'text/html') return this.html(req, res, next);
      if (this.json && type === 'application/json') {
        return this.json(req, res, next);
      }
    }
    return next();
  };

  exports.getResource = function(options) {
    var collectionIsRelation, resource, _ref, _ref2, _ref3, _ref4, _ref5, _ref6;
    if (!options.schema) throw 'No schema defined';
    if (!options.name) throw 'No schema name defined';
    if (!options.model) throw 'No schema model defined';
    if ((_ref = options.urlName) == null) options.urlName = options.name;
    if ((_ref2 = options.where) == null) options.where = 'id';
    if ((_ref3 = options.addPlaceholderForEmpty) == null) {
      options.addPlaceholderForEmpty = false;
    }
    if (options.collection) {
      collectionIsRelation = true;
    } else {
      collectionIsRelation = false;
      if ((_ref4 = options.collection) == null) options.collection = options.model;
    }
    if ((_ref5 = options.toJSON) == null) {
      options.toJSON = function(items, req) {
        return items;
      };
    }
    if ((_ref6 = options.seek) == null) {
      options.seek = function(request, constraints, callback) {
        var collection;
        if (collectionIsRelation) {
          collection = options.collection;
          if (typeof options.collection === 'function') {
            collection = options.collection(request);
          }
          collection({
            where: constraints
          }, function(err, items) {
            if (!items) items = [];
            return callback(err, items);
          });
          return;
        }
        if (constraints.id) {
          options.model.find(constraints.id, function(err, item) {
            return callback(err, [item]);
          });
          return;
        }
        return options.model.all({
          where: constraints
        }, function(err, items) {
          if (!items) items = [];
          return callback(err, items);
        });
      };
    }
    resource = {
      id: options.urlName,
      load: function(request, where, callback) {
        var whereQuery;
        whereQuery = {};
        whereQuery[options.where] = where;
        return options.seek(request, whereQuery, function(err, items) {
          if (err) return callback(err, null);
          return callback(null, items[0]);
        });
      },
      index: {
        html: function(req, res) {
          return options.seek(req, {}, function(err, items) {
            var blankItem, defs, property, _ref7;
            if (options.addPlaceholderForEmpty && items.length === 0) {
              blankItem = {};
              _ref7 = options.schema.definitions[options.name].properties;
              for (property in _ref7) {
                defs = _ref7[property];
                blankItem[property] = '';
              }
              blankItem['id'] = 'mgd:placeholder';
              items.push(blankItem);
            }
            return res.render("" + options.urlName + "/index", {
              locals: {
                items: items,
                as: 'item'
              }
            });
          });
        },
        json: function(req, res) {
          return options.seek(req, {}, function(err, items) {
            return res.send(options.toJSON(items, req));
          });
        },
        "default": exports.contentNegotiator
      },
      create: function(req, res) {
        var collection, newItem, property, value, _ref7;
        if (collectionIsRelation) {
          collection = options.collection;
          if (typeof options.collection === 'function') {
            collection = options.collection(req);
          }
          newItem = collection.build();
          _ref7 = req.body;
          for (property in _ref7) {
            value = _ref7[property];
            newItem[property] = value;
          }
          newItem.save(function(err, item) {
            return res.send(options.toJSON(item, req));
          });
          return;
        }
        return options.collection.create(req.body, function(err, item) {
          return res.send(options.toJSON(item, req));
        });
      },
      update: function(req, res) {
        return req[options.urlName].updateAttributes(req.body, function(err, item) {
          return res.send(options.toJSON(req[options.urlName], req));
        });
      },
      destroy: function(req, res) {
        return req[options.urlName].destroy(function(err, item) {
          return res.send(options.toJSON(req[options.urlName], req));
        });
      },
      show: {
        html: function(req, res) {
          return res.render("" + options.urlName + "/show", {
            locals: {
              item: req[options.urlName],
              as: options.urlName
            }
          });
        },
        json: function(req, res) {
          return res.send(options.toJSON(req[options.urlName], req));
        },
        "default": exports.contentNegotiator
      }
    };
    if (options.base) resource.base = options.base;
    return resource;
  };
